@@ -1,3 +1,4 @@
+import asyncio
 import json
 import uuid
 
@@ -6,6 +7,11 @@ import redis.asyncio as redis
 from asyncredisrpc import REDIS_PREFIX
 
 
+def make_request(name, *args, **kwargs):
+    req_id = uuid.uuid4().hex
+    return req_id, {'id': req_id, 'name': name, 'args': args, 'kwargs': kwargs}
+
+
 class AsyncClient:
     def __init__(self, queue, host='localhost', port=6379):
         self.url = f'redis://{host}:{port}'
@@ -16,8 +22,7 @@ class AsyncClient:
         self.redis = await redis.from_url(self.url)
 
     async def call(self, name, *args, **kwargs):
-        req_id = uuid.uuid4().hex
-        req = {'id': req_id, 'name': name, 'args': [args, kwargs]}
+        req_id, req = make_request(name, *args, **kwargs)
         await self.redis.rpush(self.queue, json.dumps(req))
         _, elem = await self.redis.blpop(f'{self.queue}:{req_id}')
         elem = elem.decode()
